/***************************************************************************
                          ann_ds_rec.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_ds_rec.h>

  //                   //
 // class ANN::DS_rec //
//                   //

ANN::DS_rec::~DS_rec()
{
}

const ANN::Size &
ANN::DS_rec::get_lengths() const
{
  return orig->get_lengths();
}

size_t
ANN::DS_rec::get_length() const
{
  return orig->get_length();
}

const ANN::Size &
ANN::DS_rec::get_sizes() const
{
  return orig->get_sizes();
}

size_t
ANN::DS_rec::get_size() const
{
  return orig->get_size();
}

ANN::Term &
ANN::DS_rec::term()
{
  return orig->term();
}

const ANN::Term &
ANN::DS_rec::term() const
{
  return orig->term();
}

bool
ANN::DS_rec::reset()
{
  return orig->reset();
}

void
ANN::DS_rec::feed()
{
  orig->feed();
}

bool
ANN::DS_rec::seek(size_t term_pos_)
{
  return orig->seek(term_pos_);
}

bool
ANN::DS_rec::locate(const Loc &loc)
{
  return orig->locate(loc);
}

const ANN::Loc &
ANN::DS_rec::where() const
{
  return orig->where();
}

size_t
ANN::DS_rec::which() const
{
  return orig->which();
}

